clear all;

%% Measured data
% taken by Jax and Elli
data0 = load('SRS001.m');
data1 = load('SRS002.m');

f = data0(:,1);
amp = data0(:,2);
pha = data1(:,2);

%% Frequency vector, for the model
fm = logspace(1, 6, 2000);
wm = 2*pi*fm;

%% Notch filter
% Hn = out/in = z2 / (z1+z2)
%
R1 = 1e3;
R2 = 51;
L1 = 493e-6; % measured, stock value is 470uH
C1 = 500e-12 + 100e-12; % two caps in parallel
C2 = 45e-12;  % varialbe cap imperical set to 282 kHz
%
fn = 1./(2*pi*sqrt(L1 *(C1+C2)));   % notch frequency
Z1 = R1;
Z2 = R2 + (i*wm'*L1) + 1./(i*wm'.*(C1+C2)); %
Hn = Z2./(Z1+Z2);


%% CMB Fibre Servo
% removed the temp '0', as that is not in the CMD.
% Also, the complex pole at 100k is modelled as a double pole.
po = 2*pi*[ 0, 1.35, 100e3, 100e3];
ze = 2*pi*[4e3];
kk = 7.5e16;
sys = zpk(-ze, -po, kk);
Hm = mybodesys(sys, fm);

%% Overall response
Hcmb = Hm .* Hn;

%% Measurement around the UGF
figure(1)
subplot(211)
semilogx(f, amp, 'LineWidth', 2);
axis([f(1) f(end) -20 10]);
grid on;
ylabel('Amplitude [dB]', 'FontSize', 16);
title('ALS FIBRE Servo UGF', 'FontSize', 16);

subplot(212)
semilogx(f, pha, 'LineWidth', 2);
axis([f(1) f(end) -200 200]);
grid on;
xlabel('Frequency [Hz]', 'FontSize', 16);
ylabel('Phase [deg]', 'FontSize', 16);

%print('-dpng', 'als_pll_ugf.png');


%% Notch filter response
figure(2)
subplot(211)
semilogx(fm, 20*log10(abs(Hn)), 'LineWidth', 2);
grid on;
ylabel('Amplitude [dB]', 'FontSize', 16);
title('ALS FIBRE Notch Transfer Function', 'FontSize', 16);
%legend('Measured', 'Modelled', ['UGF at ' num2str(ugfx(1)/1e3) ' kHz'], 'FontSize', 14);

subplot(212)
semilogx(fm, angle(Hn)*180/pi, 'LineWidth', 2);
grid on;
xlabel('Frequency [Hz]', 'FontSize', 16);
ylabel('Phase [deg]', 'FontSize', 16);


%% Overall response
ugfx = [28.64e3 28.64e3];
ugfy = [-20 80];

figure(3)
subplot(211)
semilogx(f, amp, ...
       fm, 20*log10(abs(Hcmb)), 'LineWidth', 2);
line(ugfx, ugfy, 'LineWidth', 2, 'Color', 'red');
axis([100 1e5 -20 80]);
grid on;
ylabel('Amplitude [dB]', 'FontSize', 16);
title('ALS FIBRE Servo Transfer Function', 'FontSize', 16);
legend('Measured', 'Modelled', ['UGF at ' num2str(ugfx(1)/1e3) ' kHz'], 'FontSize', 14);

subplot(212)
semilogx(f, pha, ...
         fm, angle(Hcmb)*180/pi, 'LineWidth', 2);
line(ugfx, [-200 200], 'LineWidth', 2, 'Color', 'red');     
axis([100 1e5 -200 200]);
grid on;
xlabel('Frequency [Hz]', 'FontSize', 16);
ylabel('Phase [deg]', 'FontSize', 16);

print('-depsc2', 'als_pll_tf.eps');
